@@ -20,16 +20,21 @@
 sourceCpp <- function(file = "",
                       code = NULL,
                       env = globalenv(),
+                      embeddedR = TRUE,
                       rebuild = FALSE,
                       showOutput = verbose,
                       verbose = getOption("verbose")) {
 
-    # resolve code into a file if necessary
+    # resolve code into a file if necessary. also track the working
+    # directory to source the R embedded code chunk within
     if (!missing(code)) {
+        rWorkingDir <- getwd()
         file <- tempfile(fileext = ".cpp")
         con <- file(file, open = "w")
         writeLines(code, con)
         close(con)
+    } else {
+        rWorkingDir <- dirname(file)
     }
 
     # resolve the file path
@@ -123,11 +128,11 @@ sourceCpp <- function(file = "",
             # examine status
             status <- attr(result, "status")
             if (!is.null(status)) {
-                cat(result, "\n")
+                cat(result, sep = "\n")
                 succeeded <- FALSE
                 stop("Error ", status, " occurred building shared library.")
             } else if (!file.exists(context$dynlibFilename)) {
-                cat(result, "\n")
+                cat(result, sep = "\n")
                 succeeded <- FALSE
                 stop("Error occurred building shared library.")
             } else {
@@ -165,8 +170,9 @@ sourceCpp <- function(file = "",
     }
 
     # source the embeddedR
-    if (length(context$embeddedR) > 0) {
+    if (embeddedR && (length(context$embeddedR) > 0)) {
         srcConn <- textConnection(context$embeddedR)
+        setwd(rWorkingDir) # will be reset by previous on.exit handler
         source(file=srcConn, echo=TRUE)
     }
 
@@ -264,7 +270,7 @@ cppFunction <- function(code,
         manipulate_this_type <- do.call( cppFunction, dots )
         res <- manipulate_this_type()
         if( ! is.null(class) ){
-            class(res) <- class    
+            class(res) <- class
         }
         res
     }
@@ -275,7 +281,7 @@ sizeof   <- .type_manipulate( "sizeof", "bytes" )
 
 print.bytes <- function( x, ...){
     writeLines( sprintf( "%d bytes (%d bits)", x, 8 * x ) )
-    invisible( x )    
+    invisible( x )
 }
 
 # Evaluate a simple c++ expression
@@ -337,10 +343,11 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
         stop("pkgdir must refer to the directory containing an R package")
     pkgDesc <- read.dcf(descFile)[1,]
     pkgname = .readPkgDescField(pkgDesc, "Package")
-    depends <- .readPkgDescField(pkgDesc, "Depends", character())
+    depends <- c(.readPkgDescField(pkgDesc, "Depends", character()),
+                 .readPkgDescField(pkgDesc, "Imports", character()))
     depends <- unique(.splitDepends(depends))
     depends <- depends[depends != "R"]
-
+                 
     # determine source directory
     srcDir <- file.path(pkgdir, "src")
     if (!file.exists(srcDir))
@@ -352,7 +359,7 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
         dir.create(rDir)
 
     # get a list of all source files
-    cppFiles <- list.files(srcDir, pattern=glob2rx("*.c*"))
+    cppFiles <- list.files(srcDir, pattern="\\.c(c|pp)$")
 
     # derive base names (will be used for modules)
     cppFileBasenames <- tools::file_path_sans_ext(cppFiles)
@@ -372,7 +379,7 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
     if (file.exists(pkgHeaderPath)) {
         pkgInclude <- paste("#include \"../inst/include/",
                             pkgHeader, "\"", sep="")
-        includes <- c(includes, pkgInclude)
+        includes <- c(pkgInclude, includes)
     }
 
     # generate exports
@@ -386,7 +393,22 @@ compileAttributes <- function(pkgdir = ".", verbose = getOption("verbose")) {
 
 # built-in C++11 plugin
 .plugins[["cpp11"]] <- function() {
-    list(env = list(PKG_CXXFLAGS ="-std=c++11"))
+    if (getRversion() >= "3.1")
+        list(env = list(USE_CXX1X = "yes"))
+    else if (.Platform$OS.type == "windows")
+        list(env = list(PKG_CXXFLAGS = "-std=c++0x"))
+    else
+        list(env = list(PKG_CXXFLAGS ="-std=c++11"))
+}
+
+# built-in C++11 plugin for older g++ compiler
+.plugins[["cpp0x"]] <- function() {
+    list(env = list(PKG_CXXFLAGS ="-std=c++0x"))
+}
+
+# built-in C++1y plugin for C++14 and C++17 standard under development
+.plugins[["cpp1y"]] <- function() {
+    list(env = list(PKG_CXXFLAGS ="-std=c++1y"))
 }
 
 ## built-in OpenMP++11 plugin
@@ -406,7 +428,7 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
 
     args <- names(formals(func))
 
-    body <- quote( .Call( EXTERNALNAME, ARG ) )[ c(1:2, rep(3, length(args))) ]
+    body <- quote( CALL_PLACEHOLDER ( EXTERNALNAME, ARG ) )[ c(1:2, rep(3, length(args))) ]
 
     for (i in seq(along = args))
         body[[i+2]] <- as.symbol(args[i])
@@ -502,7 +524,7 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
 
 # Lookup a plugin
 .findPlugin <- function(pluginName) {
-    
+
     plugin <- .plugins[[pluginName]]
     if (is.null(plugin))
         stop("Inline plugin '", pluginName, "' could not be found ",
@@ -581,13 +603,6 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
     # if there is no buildEnv from a plugin then use the Rcpp plugin
     if (length(buildEnv) == 0) {
         buildEnv <- inlineCxxPlugin()$env
-    } else {
-        # we are using a plugin -- confirm that the plugin includes the Rcpp
-        # PKG_LIBS and if it doesn't then add them
-        pkgLibs <- buildEnv$PKG_LIBS
-        rcppLibs <- Rcpp::RcppLdFlags()
-        if (is.null(pkgLibs) || !grepl(rcppLibs, pkgLibs, fixed = TRUE))
-            buildEnv$PKG_LIBS <- paste(pkgLibs, rcppLibs)
     }
 
     # set CLINK_CPPFLAGS based on the LinkingTo dependencies
@@ -914,4 +929,3 @@ sourceCppFunction <- function(func, isVoid, dll, symbol) {
     }
     .hasDevelTools
 }
-
