@@ -1,41 +1,17 @@
 ### R code from vignette source 'Rcpp-extending.Rnw'
 
 ###################################################
-### code chunk number 1: Rcpp-extending.Rnw:36-38
+### code chunk number 1: Rcpp-extending.Rnw:43-48
 ###################################################
 prettyVersion <- packageDescription("Rcpp")$Version
 prettyDate <- format(Sys.Date(), "%B %e, %Y")
-
-
-###################################################
-### code chunk number 2: Rcpp-extending.Rnw:45-67
-###################################################
-link <- function( f, package, text = f, root = "http://finzi.psych.upenn.edu/R/library/" ){
-	h <- if( missing(package) ) {
-		as.character( help( f ) )
-	} else {
-		as.character( help( f, package = paste( package, sep = "" ) ) )
-	}
-	if( ! length(h) ){
-		sprintf( "\\\\textbf{%s}", f )
-	} else {
-		rx <- "^.*/([^/]*?)/help/(.*?)$"
-		package <- sub( rx, "\\1", h, perl = TRUE )
-		page <- sub( rx, "\\2", h, perl = TRUE )
-		sprintf( "\\\\href{%s%s/html/%s.html}{\\\\texttt{%s}}", root, package, page, text )
-	}
-}
-linkS4class <- function( cl, package, text = cl, root = "http://finzi.psych.upenn.edu/R/library/" ){
-	link( sprintf("%s-class", cl), package, text, root )
-}
-
 require(inline)
 require(highlight)
 require(Rcpp)
 
 
 ###################################################
-### code chunk number 4: Rcpp-extending.Rnw:105-121
+### code chunk number 3: Rcpp-extending.Rnw:90-106
 ###################################################
 code <- '
 // we get a list from R
@@ -56,13 +32,13 @@ writeLines( code, "code.cpp" )
 
 
 ###################################################
-### code chunk number 5: Rcpp-extending.Rnw:123-124
+### code chunk number 4: Rcpp-extending.Rnw:108-109
 ###################################################
 external_highlight( "code.cpp", type = "LATEX", doc = FALSE )
 
 
 ###################################################
-### code chunk number 6: Rcpp-extending.Rnw:127-133
+### code chunk number 5: Rcpp-extending.Rnw:112-118
 ###################################################
 fx <- cxxfunction( signature( input_ = "list"),
 	paste( readLines( "code.cpp" ), collapse = "\n" ),
@@ -73,7 +49,7 @@ fx( input )
 
 
 ###################################################
-### code chunk number 14: Rcpp-extending.Rnw:339-340
+### code chunk number 13: Rcpp-extending.Rnw:324-325
 ###################################################
 unlink( "code.cpp" )
 
