@@ -2,7 +2,7 @@
 //
 // InternalFunction.h: Rcpp R/C++ interface class library -- exposing C++ functions
 //
-// Copyright (C) 2010 - 2012 Dirk Eddelbuettel and Romain Francois
+// Copyright (C) 2010 - 2013 Dirk Eddelbuettel and Romain Francois
 //
 // This file is part of Rcpp.
 //
@@ -25,27 +25,27 @@
 #include <RcppCommon.h>
 
 #include <Rcpp/grow.h>
-#include <Rcpp/RObject.h>
 
-namespace Rcpp{ 
+namespace Rcpp{
 
-/** 
- * functions
- */
-class InternalFunction : public RObject {
-public:
+    RCPP_API_CLASS(InternalFunction_Impl) {
+    public:
 
-#include <Rcpp/generated/InternalFunction__ctors.h>	
-		
-private:
-	
-	inline void set( SEXP xp){
-		Environment RCPP = Environment::Rcpp_namespace() ;
-		Function intf = RCPP["internal_function"] ;
-		setSEXP( intf( xp ) ) ; 
-	}
-	
-};
+        RCPP_GENERATE_CTOR_ASSIGN(InternalFunction_Impl)
+
+        #include <Rcpp/generated/InternalFunction__ctors.h>
+
+    private:
+
+        inline void set( SEXP xp){
+            Environment RCPP = Environment::Rcpp_namespace() ;
+            Function intf = RCPP["internal_function"] ;
+            Storage::set__( intf( xp ) ) ;
+        }
+
+    };
+
+    typedef InternalFunction_Impl<PreserveStorage> InternalFunction ;
 
 } // namespace Rcpp
 
