@@ -1,6 +1,6 @@
 // -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 4 -*-
 //
-// rnbinom.h: Rcpp R/C++ interface class library -- 
+// rnbinom.h: Rcpp R/C++ interface class library --
 //
 // Copyright (C) 2010 - 2012 Douglas Bates, Dirk Eddelbuettel and Romain Francois
 //
@@ -25,34 +25,23 @@
 namespace Rcpp {
 	namespace stats {
 
-	    template <bool seed>
-		class NBinomGenerator : public ::Rcpp::Generator<seed,double> {
+
+		class NBinomGenerator : public ::Rcpp::Generator<double> {
 		public:
-	
-			NBinomGenerator( double siz_, double prob_ ) : 
+
+			NBinomGenerator( double siz_, double prob_ ) :
 				siz(siz_), lambda( (1-prob_)/prob_ ) {}
-	
+
 			inline double operator()() const {
-				return ::Rf_rpois( ::Rf_rgamma( siz, lambda ) ) ; 
+				return ::Rf_rpois( ::Rf_rgamma( siz, lambda ) ) ;
 			}
-	
+
 		private:
 			double siz ;
 			double lambda ;
 		} ;
 	} // stats
 
-	// Please make sure you to read Section 6.3 of "Writing R Extensions"
-	// about the need to call GetRNGstate() and PutRNGstate() when using 
-	// the random number generators provided by R.
-	inline NumericVector rnbinom( int n, double siz, double prob ){
-		if(!R_FINITE(siz) || !R_FINITE(prob) || siz <= 0 || prob <= 0 || prob > 1)
-			/* prob = 1 is ok, PR#1218 */
-			return NumericVector( n, R_NaN ) ;
-    
-		return NumericVector( n, stats::NBinomGenerator<false>( siz, prob ) ) ;
-	}
-
 } // Rcpp
 
 #endif
