@@ -1,6 +1,6 @@
 // -*- mode: C++; c-indent-level: 4; c-basic-offset: 4; tab-width: 4 -*-
 //
-// rwilcox.h: Rcpp R/C++ interface class library -- 
+// rwilcox.h: Rcpp R/C++ interface class library --
 //
 // Copyright (C) 2010 - 2012 Douglas Bates, Dirk Eddelbuettel and Romain Francois
 //
@@ -24,22 +24,15 @@
 
 namespace Rcpp {
     namespace stats {
-        template <bool seed>
-        class WilcoxGenerator : public Generator<seed,double>{
+
+        class WilcoxGenerator : public Generator<double>{
         public:
-            WilcoxGenerator( double mm_, double nn_) : mm(mm_), nn(nn_){} 
+            WilcoxGenerator( double mm_, double nn_) : mm(mm_), nn(nn_){}
             inline double operator()() const { return ::Rf_rwilcox(mm,nn); }
         private:
             double mm, nn ;
         } ;
-    } // stats    
-    
-	// Please make sure you to read Section 6.3 of "Writing R Extensions"
-	// about the need to call GetRNGstate() and PutRNGstate() when using 
-	// the random number generators provided by R.
-	inline NumericVector rwilcox( int n, double mm, double nn ){
-		return NumericVector( n, stats::WilcoxGenerator<false>(mm, nn) ) ;
-	}
+    } // stats
 
 } // Rcpp
 
